==> home-library-jcr-1.4.1-20140911.001620-76-sources.jar: org/gcube/common/homelibrary/jcr/workspace/folder/items/JCRExternalImage.java <==
package org.gcube.common.homelibrary.jcr.workspace.folder.items;

import java.io.IOException;
import java.io.InputStream;

import javax.jcr.Node;
import javax.jcr.RepositoryException;

import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.common.homelibrary.home.workspace.folder.FolderItemType;
import org.gcube.common.homelibrary.home.workspace.folder.items.ExternalImage;
import org.gcube.common.homelibrary.jcr.workspace.JCRWorkspace;
import org.gcube.contentmanagement.blobstorage.transport.backend.RemoteBackendException;

public class JCRExternalImage extends JCRExternalFile implements
		ExternalImage {
	
	public JCRExternalImage(JCRWorkspace workspace, Node node) throws RepositoryException  {
		super(workspace, node,ContentType.IMAGE);
		
	}
	
	public JCRExternalImage(JCRWorkspace workspace, Node node, String name, String description,
			String mimeType, InputStream data) throws RepositoryException, IOException, RemoteBackendException   {
		super(workspace,node,name,description,mimeType,ContentType.IMAGE,data);
	}

	@Override
	public int getWidth() {
		return ((JCRImage)content).getWidth();
	}

	@Override
	public int getHeight() {
		return ((JCRImage)content).getHeight();
	}

	@Override
	public InputStream getThumbnail() throws InternalErrorException {
		return ((JCRImage)content).getThumbnail();
	}

	@Override
	public int getThumbnailWidth() {
		return ((JCRImage)content).getThumbnailWidth();
	}

	@Override
	public int getThumbnailHeight() {
		return ((JCRImage)content).getThumbnailHeight();
	}

	@Override
	public long getThumbnailLength() throws InternalErrorException {
		return ((JCRImage)content).getThumbnailLength();
	}

	@Override
	public FolderItemType getFolderItemType() {
		return FolderItemType.EXTERNAL_IMAGE;
	}


	@Override
	public void updateInfo(String mimeType) throws InternalErrorException {
		super.updateInfo(mimeType);
	}
	

}

==> home-library-jcr-1.5.0-20141030.014425-79-sources.jar: org/gcube/common/homelibrary/jcr/workspace/folder/items/JCRExternalImage.java <==
package org.gcube.common.homelibrary.jcr.workspace.folder.items;

import java.io.IOException;
import java.io.InputStream;

import javax.jcr.Node;
import javax.jcr.RepositoryException;

import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.common.homelibrary.home.workspace.folder.FolderItemType;
import org.gcube.common.homelibrary.home.workspace.folder.items.ExternalImage;
import org.gcube.common.homelibrary.jcr.workspace.JCRWorkspace;
import org.gcube.contentmanagement.blobstorage.transport.backend.RemoteBackendException;

public class JCRExternalImage extends JCRExternalFile implements
		ExternalImage {
	
	public JCRExternalImage(JCRWorkspace workspace, Node node) throws RepositoryException  {
		super(workspace, node,ContentType.IMAGE);
		
	}
	
	public JCRExternalImage(JCRWorkspace workspace, Node node, String name, String description,
			String mimeType, InputStream data) throws RepositoryException, IOException, RemoteBackendException   {
		super(workspace,node,name,description,mimeType,ContentType.IMAGE,data);
	}

	@Override
	public int getWidth() {
		return ((JCRImage)content).getWidth();
	}

	@Override
	public int getHeight() {
		return ((JCRImage)content).getHeight();
	}

	@Override
	public InputStream getThumbnail() throws InternalErrorException {
		return ((JCRImage)content).getThumbnail();
	}

	@Override
	public int getThumbnailWidth() {
		return ((JCRImage)content).getThumbnailWidth();
	}

	@Override
	public int getThumbnailHeight() {
		return ((JCRImage)content).getThumbnailHeight();
	}

	@Override
	public long getThumbnailLength() throws InternalErrorException {
		return ((JCRImage)content).getThumbnailLength();
	}

	@Override
	public FolderItemType getFolderItemType() {
		return FolderItemType.EXTERNAL_IMAGE;
	}


	@Override
	public void updateInfo(String mimeType, long size) throws InternalErrorException {
		super.updateInfo(mimeType, size);
	}
	

}
